.wp-block-jetpack-rating-star{line-height:0;margin-bottom:1.5em;stroke-width:0}.wp-block-jetpack-rating-star .is-rating-unfilled{fill-opacity:.33}.wp-block-jetpack-rating-star .jetpack-ratings-button{border-radius:2px;display:inline-flex}.wp-block-jetpack-rating-star .jetpack-ratings-button:focus{box-shadow:0 0 0 1px currentColor;outline:2px solid #0000}.wp-block-jetpack-rating-star>p{border:0;clip:rect(1px,1px,1px,1px);clip-path:inset(50%);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;word-wrap:normal!important}.wp-block-jetpack-rating-star>span{display:inline-flex!important;margin-inline-end:.3em}.wp-block-jetpack-rating-star .jetpack-ratings-button span,.wp-block-jetpack-rating-star>span span{display:inline-flex;flex-shrink:0;overflow:hidden;width:12px}.wp-block-jetpack-rating-star .jetpack-ratings-button span svg,.wp-block-jetpack-rating-star>span span svg{flex-shrink:0}.wp-block-jetpack-rating-star .jetpack-ratings-button span:nth-child(2n),.wp-block-jetpack-rating-star>span span:nth-child(2n){justify-content:flex-end}.wp-block-jetpack-rating-star svg{display:inline-block!important;max-width:none!important}.wp-block-jetpack-rating-star.is-style-outlined{stroke-width:2px}.wp-block-jetpack-rating-star.is-style-outlined .is-rating-unfilled{fill:#0000}.wp-block-jetpack-rating-star .jetpack-ratings-button{margin-inline-end:.3em}