.wp-block-jetpack-google-docs-embed{border:1px solid #ccc;flex-basis:50%}.wp-block-jetpack-google-docs-embed.aligncenter{margin-left:auto;margin-right:auto}.wp-block-jetpack-google-docs-embed.alignleft,.wp-block-jetpack-google-docs-embed.alignright{margin-bottom:20px;max-width:600px}@media only screen and (min-width:600px){.wp-block-jetpack-google-docs-embed.alignleft{float:right;margin-left:20px!important}.wp-block-jetpack-google-docs-embed.alignright{float:left;margin-right:20px!important}}.wp-block-jetpack-google-docs-embed.ar-50 .wp-block-jetpack-google-docs-embed__wrapper:before{padding-top:50%}.wp-block-jetpack-google-docs-embed.ar-100 .wp-block-jetpack-google-docs-embed__wrapper:before{padding-top:100%}.wp-block-jetpack-google-docs-embed__wrapper{position:relative}.wp-block-jetpack-google-docs-embed__wrapper:before{content:"";display:block;padding-top:50%}.wp-block-jetpack-google-docs-embed__wrapper--error:before{content:none}.wp-block-jetpack-google-docs-embed__error-msg{background-color:#f8f9fa;color:#333;font-size:16px;margin:0;padding:20px}.wp-block-jetpack-google-docs-embed__error-msg:before{background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' fill='none'%3E%3Cpath fill='%231E2935' fill-rule='evenodd' d='M4.125 12A7.875 7.875 0 0 1 12 4.124a7.875 7.875 0 1 1-7.875 7.874ZM12 3a9 9 0 1 0 0 17.999A9 9 0 1 0 12 3m.041 5.28c.31 0 .563.253.563.563v4.5a.562.562 0 0 1-1.125 0v-4.5c0-.31.252-.562.562-.562Zm-.562 7.313c0-.31.252-.563.562-.563h.011a.562.562 0 0 1 0 1.125h-.01a.56.56 0 0 1-.563-.562' clip-rule='evenodd'/%3E%3C/svg%3E");background-position:top;background-repeat:no-repeat;background-size:20px;content:"";display:inline-block;height:20px;margin-inline-end:8px;position:relative;top:4px;width:20px}.wp-block-jetpack-google-docs-embed__error-msg a{color:#333;text-decoration:underline}.wp-block-jetpack-google-docs-embed__error-msg a:focus,.wp-block-jetpack-google-docs-embed__error-msg a:hover{text-decoration:none}.wp-block-jetpack-google-docs-embed .loader{background-color:#fff;display:none;height:100%;position:absolute;text-align:center;top:0;width:100%;z-index:99}.wp-block-jetpack-google-docs-embed .loader.is-active{display:block}.wp-block-jetpack-google-docs-embed .loader span{position:relative;top:50%;transform:translateY(-50%)}.wp-block-jetpack-google-docs-embed iframe{bottom:0;height:100%;left:0;max-width:100%;position:absolute;right:0;top:0;width:100%}.editor-styles-wrapper .wp-block-jetpack-google-docs-embed figure{margin:0}.editor-styles-wrapper [data-align=left] .wp-block-jetpack-google-docs-embed,.editor-styles-wrapper [data-align=right] .wp-block-jetpack-google-docs-embed{width:auto}.editor-styles-wrapper [data-align=left] .wp-block-jetpack-google-docs-embed__wrapper:before,.editor-styles-wrapper [data-align=right] .wp-block-jetpack-google-docs-embed__wrapper:before{content:none}.editor-styles-wrapper [data-align=left] iframe,.editor-styles-wrapper [data-align=right] iframe{position:relative}.editor-styles-wrapper [data-align=left] .wp-block-jetpack-google-docs-embed{margin-left:20px}.editor-styles-wrapper [data-align=right] .wp-block-jetpack-google-docs-embed{margin-right:20px}html[amp] .wp-block-jetpack-google-docs-embed.alignleft,html[amp] .wp-block-jetpack-google-docs-embed.alignright{float:none}html[amp] .wp-block-jetpack-google-docs-embed__wrapper:before{content:none}html[amp] .wp-block-jetpack-google-docs-embed__error-msg:before{background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3E%3Cpath fill='%231E2935' d='M1.5 3.5v11h11V10H14v5a1 1 0 0 1-1 1H1a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1h5v1.5z'/%3E%3Cpath fill='%231E2935' d='m15.922 1.178-8.907 8.907-1.06-1.06L14.86.118l1.06 1.06Z'/%3E%3Cpath fill='%231E2935' d='M7.5 0H16v1.5H7.5z'/%3E%3Cpath fill='%231E2935' d='M16 0v8.5h-1.5V0z'/%3E%3C/svg%3E");background-size:12px;height:12px;top:1px;width:12px}html[amp] .wp-block-jetpack-google-docs-embed .loader{display:none}