.wp-block-jetpack-instagram-gallery__grid{align-content:stretch;display:flex;flex-direction:row;flex-wrap:wrap;justify-content:flex-start}.wp-block-jetpack-instagram-gallery__grid .wp-block-jetpack-instagram-gallery__grid-post{box-sizing:border-box;display:block;line-height:0;position:relative}.wp-block-jetpack-instagram-gallery__grid img{height:auto;width:100%}.wp-block-jetpack-instagram-gallery__grid-columns-1 .wp-block-jetpack-instagram-gallery__grid-post{width:100%}.wp-block-jetpack-instagram-gallery__grid-columns-2 .wp-block-jetpack-instagram-gallery__grid-post{width:50%}.wp-block-jetpack-instagram-gallery__grid-columns-3 .wp-block-jetpack-instagram-gallery__grid-post{width:33.33333%}.wp-block-jetpack-instagram-gallery__grid-columns-4 .wp-block-jetpack-instagram-gallery__grid-post{width:25%}.wp-block-jetpack-instagram-gallery__grid-columns-5 .wp-block-jetpack-instagram-gallery__grid-post{width:20%}.wp-block-jetpack-instagram-gallery__grid-columns-6 .wp-block-jetpack-instagram-gallery__grid-post{width:16.66667%}@media(max-width:600px){.wp-block-jetpack-instagram-gallery__grid.is-stacked-on-mobile .wp-block-jetpack-instagram-gallery__grid-post{width:100%}}@supports(display:grid){.wp-block-jetpack-instagram-gallery__grid{display:grid;grid-gap:10px;grid-auto-columns:1fr}@media(max-width:600px){.wp-block-jetpack-instagram-gallery__grid.is-stacked-on-mobile{display:block}.wp-block-jetpack-instagram-gallery__grid.is-stacked-on-mobile .wp-block-jetpack-instagram-gallery__grid-post{padding:var(--latest-instagram-posts-spacing)}}.wp-block-jetpack-instagram-gallery__grid .wp-block-jetpack-instagram-gallery__grid-post{width:auto}.wp-block-jetpack-instagram-gallery__grid .wp-block-jetpack-instagram-gallery__grid-post img{height:100%;object-fit:cover}.wp-block-jetpack-instagram-gallery__grid-columns-1{grid-template-columns:repeat(1,1fr)}.wp-block-jetpack-instagram-gallery__grid-columns-2{grid-template-columns:repeat(2,1fr)}.wp-block-jetpack-instagram-gallery__grid-columns-3{grid-template-columns:repeat(3,1fr)}.wp-block-jetpack-instagram-gallery__grid-columns-4{grid-template-columns:repeat(4,1fr)}.wp-block-jetpack-instagram-gallery__grid-columns-5{grid-template-columns:repeat(5,1fr)}.wp-block-jetpack-instagram-gallery__grid-columns-6{grid-template-columns:repeat(6,1fr)}}@supports(object-fit:cover){.wp-block-jetpack-instagram-gallery__grid-post img{height:100%;object-fit:cover}}